Welcome to Kingdon's documentation!
======================================

`✨ Try kingdon in your browser ✨ <https://tbuli.github.io/teahouse/>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   workings
   examples/index
   contributing
   authors
   module_docs
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
